function [Fmax Fsus IFRs] = tSPN_FI(V,tstart,tend,thresh)
%calculates maximal and sustained firing rates from an array of voltage
%traces at with different magnitudes of injected current steps

%V: array of voltage traces. Time increases in the 1st dimension, injected
%   current magnitude is incremented in 2nd or 3rd dimension
%tstart: time in ms at which depolarizing step starts
%tend: time in ms at which depolarizing step ends
%thresh (optional): threshold for spike detection in mV. Default is 0mV.

%Fmax: vector of maximal firing rates for each step, in Hz
%Fsus: vector of sustained firing rates for each step, in Hz
%IFRs: cell array with instantaneous firing rates for each step, in Hz

if nargin==3
    thresh = 0;
end

V=squeeze(V);

Fmax = nan(1,size(V,2));
Fsus = Fmax;
IFRs = cell(1,size(V,2));

for jnd = 1:size(V,2)
    ds = find(diff(V(:,jnd)>thresh)==1);
    de = find(diff(V(:,jnd)>thresh)==-1);
    peaks = zeros(1,length(de));
    for ind = 1:length(de)
       [mx mi] = max(V(ds(ind):de(ind),jnd));
       peaks(ind) = ds(ind)+mi-1;
    end
    IFR = 10000./diff(peaks);
    if ~isempty(IFR)
        Fmax(jnd) = IFR(1);
    end
    if length(peaks)>=4 && all(peaks(end-3:end)>mean([tstart tend]))
        Fsus(jnd) = mean(IFR(end-2:end));
    end
    IFRs{jnd}=IFR;
end 