%% Run this section to generate a cellular response to injected current

% parameters for model cell in Fig. 4A
gmax = [300 2000 1.2 30 70 80 1 2 100]; 

% determine holding current to hold cell at -70mV
vhold = -70;
[ihold y0] = tSPN_ihold(gmax,vhold);

% create stimulus waveform, a 3s 50pA pulse
dt = 0.1;           %timestep is set at 0.1ms
duration = 5000;    %5000 ms (5 second) duration
tstart = 1000;      %start pulse at 1s
tend = 4000;        %end pulse at 4s
iinj = 50; %inject 100 pA

iclamp = zeros(duration/dt,1);
iclamp(tstart/dt:tend/dt) = iinj;
iclamp = iclamp + ihold;

%run the simulation
[V I] = tSPN(gmax,iclamp,y0);
t = (1:length(V))*dt;
plot(t,V)

%% Run this section to generate a cellular response to synaptic input
% parameters for standard cell
gmax = [300 2000 1.2 10 10 10 0 1 100]; 

% determine holding current to hold cell at -60mV
vhold = -60;
[ihold y0] = tSPN_ihold(gmax,vhold);

%create synaptic conductance template
event_time = [1000 2000 3000 3100];
event_scale = [2 3 2 2];
gsyn = tSPN_gsyn(event_time, event_scale);

%create stimulus waveform, constant holding current
dt = 0.1;           %timestep is set at 0.1ms
duration = 5000;    %5000 ms (5 second) duration
iclamp = zeros(duration/dt,1)+ihold;

%run the simulation
[V I] = tSPN(gmax,iclamp,y0,gsyn);
t = (1:length(V))*dt;
plot(t,V)
